@@ -1,7 +1,7 @@
 package WebService::Client;
 use Moo::Role;
 
-our $VERSION = '0.0202'; # VERSION
+our $VERSION = '0.0203'; # VERSION
 
 use Carp qw(croak);
 use HTTP::Request::Common qw(DELETE GET POST PUT);
@@ -48,16 +48,14 @@ sub post {
     my ($self, $path, $params, %args) = @_;
     my $headers = $self->_headers(%args);
     my $url = $self->_url($path);
-    $params = encode_json $params if $params and $self->content_type =~ /json/;
-    return $self->req(POST $url, %$headers, content => $params);
+    return $self->req(POST $url, %$headers, _content($params, $headers));
 }
 
 sub put {
     my ($self, $path, $params, %args) = @_;
     my $headers = $self->_headers(%args);
     my $url = $self->_url($path);
-    $params = encode_json $params if $params and $self->content_type =~ /json/;
-    return $self->req(PUT $url, %$headers, content => $params);
+    return $self->req(PUT $url, %$headers, _content($params, $headers));
 }
 
 sub delete {
@@ -86,6 +84,12 @@ sub req {
     return $res->content ? decode_json($res->content) : 1;
 }
 
+sub log {
+    my ($self, $msg) = @_;
+    return unless $self->logger;
+    $self->logger->DEBUG($msg);
+}
+
 sub _url {
     my ($self, $path) = @_;
     croak 'The path is missing' unless defined $path;
@@ -97,7 +101,7 @@ sub _headers {
     my $headers = $args{headers} || {};
     croak 'The headers param must be a hashref' unless 'HASH' eq ref $headers;
     $headers->{content_type} = $self->content_type
-        unless grep /content.type/i, keys %$headers;
+        unless _content_type($headers);
     return $headers;
 }
 
@@ -111,10 +115,21 @@ sub _log_response {
     $self->log(ref($self) . " RESPONSE:\n" . $res->as_string);
 }
 
-sub log {
-    my ($self, $msg) = @_;
-    return unless $self->logger;
-    $self->logger->DEBUG($msg);
+sub _content_type {
+    my ($headers) = @_;
+    return $headers->{'Content-Type'}
+        || $headers->{'content-type'}
+        || $headers->{content_type};
+}
+
+sub _content {
+    my ($params, $headers) = @_;
+    my @content;
+    if (defined $params) {
+        $params = encode_json $params if _content_type($headers) =~ /json/;
+        @content = ( content => $params );
+    }
+    return @content;
 }
 
 # ABSTRACT: A base role for quickly and easily creating web service clients
@@ -134,7 +149,7 @@ WebService::Client - A base role for quickly and easily creating web service cli
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -186,39 +201,6 @@ same boilerplate code independent of the web service.
 This module does the boring boilerplate for you so you can just focus on
 the fun part - writing the web service specific code.
 
-It is important to note that this only supports JSON based web services.
-If your web service does not support JSON, then I am sorry.
-
-=head1 ATTRIBUTES
-
-=head2 base_url
-
-This is the only attribute that is required.
-This is the base url that all request will be made against.
-
-=head2 ua
-
-Optional. A proper default LWP::UserAgent will be created for you.
-
-=head2 timeout
-
-Optional.
-Default is 10.
-
-=head2 retries
-
-Optional.
-Default is 0.
-
-=head2 logger
-
-Optional.
-
-=head2 content_type
-
-Optional.
-Default is C<'application/json'>.
-
 =head1 METHODS
 
 These are the methods this role composes into your class.
@@ -282,6 +264,36 @@ Here is a contrived example:
 
 Logs a message using the provided logger.
 
+=head1 ATTRIBUTES
+
+=head2 base_url
+
+This is the only attribute that is required.
+This is the base url that all request will be made against.
+
+=head2 ua
+
+Optional. A proper default LWP::UserAgent will be created for you.
+
+=head2 timeout
+
+Optional.
+Default is 10.
+
+=head2 retries
+
+Optional.
+Default is 0.
+
+=head2 logger
+
+Optional.
+
+=head2 content_type
+
+Optional.
+Default is C<'application/json'>.
+
 =head1 EXAMPLES
 
 Here are some examples of web service clients built with this role.
@@ -305,6 +317,10 @@ L<WebService::Lob>
 
 L<WebService::SmartyStreets>
 
+=item *
+
+L<WebService::Stripe>
+
 =back
 
 =head1 SEE ALSO
